<?php
/**
 * Notifications
 *
 * The GoldAddons plugin admin notifications.
 *
 * @package GoldAddons for Elementor
 * @since 1.0.4
 */

namespace GoldAddons;

// Exit if accessed directly.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Notifications {
    
    /**
	 * Instance
	 *
	 * Single instance of this object.
	 *
	 * @since 1.0.8
	 * @access public
	 * @var null|object
	 */
	public static $instance = null;

	/**
	 * Get Instance
	 *
	 * Access the single instance of this class.
	 *
	 * @since 1.0.8
	 * @access public
	 * @return object
	 */
	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
    
    /**
     * Class Constructor
     */
    function __construct() {
        
        add_action( 'admin_notices', [ $this, 'gapro_not_installed__notice' ] );
		add_action( 'admin_notices', [ $this, 'goldaddons_promo' ] );
		add_action( 'admin_notices', [ $this, 'try_componentz' ] );
        
    }
    
    /**
     * GAPRO not Installed
     *
     * @since 1.0.4
	 * @access public
	 * @return mixed
     */
    public function gapro_not_installed__notice() {
        $license = unserialize( get_option( '_goldaddons_license' ) );
        $license = isset( $license['status'] ) ? true : false;
        if( $license && ! is_plugin_active( 'gold-addons-pro-for-elementor/gold-addons-pro-for-elementor.php' ) ) {
            echo '<div class="notice notice-info is-dismissible">';
                echo '<p>'. sprintf( '%s <a href="%s" target="_blank">%s</a> %s <a href="%s" target="_blank">%s</a>', esc_html__( 'GoldAddons for Elementor license is activated successfully ! However it seems that you have not installed or activated', 'gold-addons-for-elementor' ), 'https://goldaddons.com/my-account/downloads/', 'GoldAddons PRO for Elementor', esc_html__( 'plugin so premium features are not enabled.', 'gold-addons-for-elementor' ), 'https://goldaddons.com/documentation/', esc_html__( 'Guide', 'gold-addons-for-elementor' ) ) .'</p>';
            echo '</div>';
        }
    }

	/**
	 * GoldAddons Promo
	 * 
	 * @since 1.1.5
	 * @access public
	 * @return mixed
	 */
	public function goldaddons_promo() {
		if ( isset( $_GET['goldaddons-promo-close'] ) && !empty( $_GET['goldaddons-promo-close'] ) ) {
			set_transient( '_goldaddons_promo_closed', true, 72 * HOUR_IN_SECONDS );
		}

		if ( get_transient( '_goldaddons_promo_closed' ) ) {
			return;
		}

		echo '<div class="notice notice-info is-dismissible">';
			echo '<h3>30% discount on GoldAddons PRO plugin! Use next promo code: <strong style="color:gold;">GA30</strong> <a href="https://goldaddons.com/pricing/" target="_blank">Check Now</a> or <a href="?goldaddons-promo-close=1">Do not show</a></h3>';
		echo '</div>';
	}

	/**
	 * Try Componentz
	 * 
	 * @since 1.1.5
	 * @access public
	 * @return mixed
	 */
	public function try_componentz() {
		if ( isset( $_GET['try-componentz'] ) && !empty( $_GET['try-componentz'] ) ) {
			set_transient( '_try_componentz_dismiss', true, 48 * HOUR_IN_SECONDS );
		}
		
		if ( get_transient( '_try_componentz_dismiss' ) ) {
			return;
		}

		echo '<div class="notice notice-info is-dismissible">';
			echo '<p>'. sprintf( '%s <a href="%s"><strong>%s</strong></a>', 'Try our new <a href="https://componentz.co" target="_blank"><strong>componentz</strong></a> theme! High quality coding standards, big documentation and support for many popular plugins.', get_admin_url() . 'theme-install.php?theme=componentz', 'Try Now' ) .' or <a href="?try-componentz=dismiss">Do not show again</a></p>';
		echo '</div>';
	}

}

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
