<?php
/**
 * General
 *
 * The GoldAddons plugin settings main page.
 *
 * @package GoldAddons for Elementor
 * @since 1.0.4
 * @since 1.0.8 Updated the code.
 * @return mixed
 */

// No direct access allowed.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

$plugin_data = get_plugin_data( GOLDADDONS_DIR . '/gold-addons-for-elementor.php' );
$version     = isset( $plugin_data['Version'] ) ? $plugin_data['Version'] : '';
$option      = unserialize( get_option( '_goldaddons_license' ) ); 
$sku         = isset( $option['sku'] ) ? esc_attr( $option['sku'] ) : '';
$key         = isset( $option['key'] ) ? $option['key'] : '';
$status      = isset( $option['status'] ) ? esc_html( $option['status'] ) : ''; 

$status == 'active' ? $class = 'border-primary' : $class = 'border-warning'; ?>

<div id="goldaddons-settings" class="wrap <?php echo $status; ?>">
    <div class="goldaddons-head-wrapper">
        <h1>GoldAddons <span><?php _e( 'For Elementor', 'gold-addons-for-elementor' ); ?></span></h1>
        <div class="goldaddons-website">
            <div class="plugin-version">
                <?php _e( 'Version:', 'gold-addons-for-elementor' ); ?>
                <span><?php echo esc_html( $version ); ?></span>
            </div>
        </div>
    </div>
    <form method="post">
        <?php wp_nonce_field( 'goldaddons-settings', 'goldaddons-settings-nonce' ); ?>
        <div id="ga-settings-license" class="ga-card">
            <div class="ga-card-body">
                
                <?php if( empty( $key) ) : ?>
                <div class="alert alert-notice">
                    <i class="fe-icon-info"></i>
                    <?php _e( 'Please insert your license key below.', 'gold-addons-for-elementor' ); ?>
                </div>
                <?php endif; ?>
                
                <?php if( ! empty( $key ) && 'active' == $status ) : ?>
                <div class="alert alert-success">
                    <i class="fe-icon-check-square"></i>
                    <?php _e( 'Congratulations! Your license key is successfully registered.', 'gold-addons-for-elementor' ); ?>
                </div>
                <?php endif; ?>
                
                <?php if( ! empty( $key ) && 'active' !== $status ) : ?>
                <div class="alert alert-warning">
                    <i class="fe-icon-slash"></i> 
                    <?php _e( 'Your license key is invalid.', 'gold-addons-for-elementor' ); ?>
                </div>
                <?php endif; ?>
                
                <div class="alert ga-dummy" style="display:none;">
                    <i class="ga-dummy"></i>
                    <span class="ga-dummy"></span>
                </div>
                
                <div class="license-form-wrapper">
                    <select name="goldaddons[sku]" class="form-control <?php echo esc_attr( $class ); ?>">
                        <option value=""><?php esc_html_e( 'Select license type', 'gold-addons-for-elementor' ); ?></option>
                        <option value="gaps" <?php selected( 'gaps', $sku, true ); ?>><?php esc_html_e( 'Personal', 'gold-addons-for-elementor' ); ?></option>
                        <option value="gabs" <?php selected( 'gabs', $sku, true ); ?>><?php esc_html_e( 'Business', 'gold-addons-for-elementor' ); ?></option>
                        <option value="gaul" <?php selected( 'gaul', $sku, true ); ?>><?php esc_html_e( 'Unlimited', 'gold-addons-for-elementor' ); ?></option>
                    </select>
                    
                    <input id="goldaddons-license" name="goldaddons[key]" type="text" value="<?php echo esc_attr( $key ); ?>" placeholder="<?php echo 'e.g.: A7D10N53q2IX7xfb1uS3BzUvxY-1'; ?>" class="form-control <?php echo esc_attr( $class ); ?>">
                    
                    <button id="goldaddons-register" class="btn btn-primary" type="button">
                        <i class="dashicons dashicons-update spin hidden"></i>
                        <?php _e( 'Submit', 'gold-addons-for-elementor' ); ?>
                    </button>
                </div>
                
            </div>
        </div>
    </form>
</div><!-- #goldaddons-settings -->
